==> openshift-model-5.9.0-sources.jar: io/fabric8/openshift/api/model/ClusterOperatorBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class ClusterOperatorBuilder extends io.fabric8.openshift.api.model.ClusterOperatorFluentImpl<io.fabric8.openshift.api.model.ClusterOperatorBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.ClusterOperator,io.fabric8.openshift.api.model.ClusterOperatorBuilder>{
  public ClusterOperatorBuilder() {
    this(false);
  }
  public ClusterOperatorBuilder(java.lang.Boolean validationEnabled) {
    this(new ClusterOperator(), validationEnabled);
  }
  public ClusterOperatorBuilder(io.fabric8.openshift.api.model.ClusterOperatorFluent<?> fluent) {
    this(fluent, false);
  }
  public ClusterOperatorBuilder(io.fabric8.openshift.api.model.ClusterOperatorFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new ClusterOperator(), validationEnabled);
  }
  public ClusterOperatorBuilder(io.fabric8.openshift.api.model.ClusterOperatorFluent<?> fluent,io.fabric8.openshift.api.model.ClusterOperator instance) {
    this(fluent, instance, false);
  }
  public ClusterOperatorBuilder(io.fabric8.openshift.api.model.ClusterOperatorFluent<?> fluent,io.fabric8.openshift.api.model.ClusterOperator instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withSpec(instance.getSpec()); 
    fluent.withStatus(instance.getStatus()); 
    this.validationEnabled = validationEnabled; 
  }
  public ClusterOperatorBuilder(io.fabric8.openshift.api.model.ClusterOperator instance) {
    this(instance,false);
  }
  public ClusterOperatorBuilder(io.fabric8.openshift.api.model.ClusterOperator instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.ClusterOperatorFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.ClusterOperator build() {
    ClusterOperator buildable = new ClusterOperator(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ClusterOperatorBuilder that = (ClusterOperatorBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-5.12.3-sources.jar: io/fabric8/openshift/api/model/ClusterOperatorBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class ClusterOperatorBuilder extends io.fabric8.openshift.api.model.ClusterOperatorFluentImpl<io.fabric8.openshift.api.model.ClusterOperatorBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.ClusterOperator,io.fabric8.openshift.api.model.ClusterOperatorBuilder>{
  public ClusterOperatorBuilder() {
    this(false);
  }
  public ClusterOperatorBuilder(java.lang.Boolean validationEnabled) {
    this(new ClusterOperator(), validationEnabled);
  }
  public ClusterOperatorBuilder(io.fabric8.openshift.api.model.ClusterOperatorFluent<?> fluent) {
    this(fluent, false);
  }
  public ClusterOperatorBuilder(io.fabric8.openshift.api.model.ClusterOperatorFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new ClusterOperator(), validationEnabled);
  }
  public ClusterOperatorBuilder(io.fabric8.openshift.api.model.ClusterOperatorFluent<?> fluent,io.fabric8.openshift.api.model.ClusterOperator instance) {
    this(fluent, instance, false);
  }
  public ClusterOperatorBuilder(io.fabric8.openshift.api.model.ClusterOperatorFluent<?> fluent,io.fabric8.openshift.api.model.ClusterOperator instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withSpec(instance.getSpec()); 
    fluent.withStatus(instance.getStatus()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public ClusterOperatorBuilder(io.fabric8.openshift.api.model.ClusterOperator instance) {
    this(instance,false);
  }
  public ClusterOperatorBuilder(io.fabric8.openshift.api.model.ClusterOperator instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.ClusterOperatorFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.ClusterOperator build() {
    ClusterOperator buildable = new ClusterOperator(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ClusterOperatorBuilder that = (ClusterOperatorBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
